@@ -33,7 +33,7 @@ class VariableList2D:
         self.add(arr)
 
     def add(self, arr: np.ndarray):
-        if self.vals.size == np.array([]):
+        if self.vals.size == np.array([]).size:
             self.vals = np.array([arr])
         else:
             self.vals = np.vstack((self.vals, arr))
